summaryrefslogtreecommitdiffstats
path: root/tests/spectrum
diff options
context:
space:
mode:
Diffstat (limited to 'tests/spectrum')
-rw-r--r--tests/spectrum/3rdparty/fftreal/fftreal_wrapper.cpp2
-rw-r--r--tests/spectrum/3rdparty/fftreal/fftreal_wrapper.h2
-rw-r--r--tests/spectrum/spectrumapp/engine.cpp2
-rw-r--r--tests/spectrum/spectrumapp/engine.h2
-rw-r--r--tests/spectrum/spectrumapp/frequencyspectrum.cpp2
-rw-r--r--tests/spectrum/spectrumapp/frequencyspectrum.h2
-rw-r--r--tests/spectrum/spectrumapp/main.cpp12
-rw-r--r--tests/spectrum/spectrumapp/spectrum.h2
-rw-r--r--tests/spectrum/spectrumapp/spectrumanalyser.cpp2
-rw-r--r--tests/spectrum/spectrumapp/spectrumanalyser.h2
-rw-r--r--tests/spectrum/spectrumapp/spectrumapp.pro2
-rw-r--r--tests/spectrum/spectrumapp/utils.cpp2
-rw-r--r--tests/spectrum/spectrumapp/utils.h2
-rw-r--r--tests/spectrum/spectrumapp/wavfile.cpp2
-rw-r--r--tests/spectrum/spectrumapp/wavfile.h2
15 files changed, 20 insertions, 20 deletions
diff --git a/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.cpp b/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.cpp
index 45aee653..f6fc37e0 100644
--- a/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.cpp
+++ b/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the examples of QtDataVis3D.
+** This file is part of the examples of QtDataVisualization.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Lesser General Public License as
diff --git a/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.h b/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.h
index 2fb602de..4cfa580b 100644
--- a/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.h
+++ b/tests/spectrum/3rdparty/fftreal/fftreal_wrapper.h
@@ -3,7 +3,7 @@
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the examples of QtDataVis3D.
+** This file is part of the examples of QtDataVisualization.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Lesser General Public License as
diff --git a/tests/spectrum/spectrumapp/engine.cpp b/tests/spectrum/spectrumapp/engine.cpp
index 60605223..9d049384 100644
--- a/tests/spectrum/spectrumapp/engine.cpp
+++ b/tests/spectrum/spectrumapp/engine.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/engine.h b/tests/spectrum/spectrumapp/engine.h
index cdd8373f..1ad86065 100644
--- a/tests/spectrum/spectrumapp/engine.h
+++ b/tests/spectrum/spectrumapp/engine.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/frequencyspectrum.cpp b/tests/spectrum/spectrumapp/frequencyspectrum.cpp
index 013d0454..c5f62cef 100644
--- a/tests/spectrum/spectrumapp/frequencyspectrum.cpp
+++ b/tests/spectrum/spectrumapp/frequencyspectrum.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/frequencyspectrum.h b/tests/spectrum/spectrumapp/frequencyspectrum.h
index fac9a1b7..0008985f 100644
--- a/tests/spectrum/spectrumapp/frequencyspectrum.h
+++ b/tests/spectrum/spectrumapp/frequencyspectrum.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/spectrum.h b/tests/spectrum/spectrumapp/spectrum.h
index 015989d5..97096b1c 100644
--- a/tests/spectrum/spectrumapp/spectrum.h
+++ b/tests/spectrum/spectrumapp/spectrum.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/spectrumanalyser.cpp b/tests/spectrum/spectrumapp/spectrumanalyser.cpp
index 4cebfde9..b86a851c 100644
--- a/tests/spectrum/spectrumapp/spectrumanalyser.cpp
+++ b/tests/spectrum/spectrumapp/spectrumanalyser.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/spectrumanalyser.h b/tests/spectrum/spectrumapp/spectrumanalyser.h
index 6d9291ef..0e40fe66 100644
--- a/tests/spectrum/spectrumapp/spectrumanalyser.h
+++ b/tests/spectrum/spectrumapp/spectrumanalyser.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/spectrumapp.pro b/tests/spectrum/spectrumapp/spectrumapp.pro
index 0fc0584c..940cce75 100644
--- a/tests/spectrum/spectrumapp/spectrumapp.pro
+++ b/tests/spectrum/spectrumapp/spectrumapp.pro
@@ -50,7 +50,7 @@ RESOURCES = spectrum.qrc
android {
target.path = /libs/$$ANDROID_TARGET_ARCH
} else {
- target.path = $$[QT_INSTALL_EXAMPLES]/datavis3d/spectrum
+ target.path = $$[QT_INSTALL_EXAMPLES]/datavisualization/spectrum
}
INSTALLS += target
diff --git a/tests/spectrum/spectrumapp/utils.cpp b/tests/spectrum/spectrumapp/utils.cpp
index bad6cc48..f007959c 100644
--- a/tests/spectrum/spectrumapp/utils.cpp
+++ b/tests/spectrum/spectrumapp/utils.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/utils.h b/tests/spectrum/spectrumapp/utils.h
index f0ae5633..009f895b 100644
--- a/tests/spectrum/spectrumapp/utils.h
+++ b/tests/spectrum/spectrumapp/utils.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/wavfile.cpp b/tests/spectrum/spectrumapp/wavfile.cpp
index 24482507..56dd340e 100644
--- a/tests/spectrum/spectrumapp/wavfile.cpp
+++ b/tests/spectrum/spectrumapp/wavfile.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/wavfile.h b/tests/spectrum/spectrumapp/wavfile.h
index e408911b..25673630 100644
--- a/tests/spectrum/spectrumapp/wavfile.h
+++ b/tests/spectrum/spectrumapp/wavfile.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/tests/spectrum/spectrumapp/main.cpp b/tests/spectrum/spectrumapp/main.cpp
index 89051da4..6c264516 100644
--- a/tests/spectrum/spectrumapp/main.cpp
+++ b/tests/spectrum/spectrumapp/main.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -19,9 +19,9 @@
#include "engine.h"
#include "utils.h"
-#include <QtDataVis3D/q3dbars.h>
-#include <QtDataVis3D/qbardataproxy.h>
-#include <QtDataVis3D/q3dvalueaxis.h>
+#include <QtDataVisualization/q3dbars.h>
+#include <QtDataVisualization/qbardataproxy.h>
+#include <QtDataVisualization/q3dvalueaxis.h>
#include <QGuiApplication>
#include <QAudio>
@@ -29,7 +29,7 @@
//#define USE_CONES
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
class MainApp : public QObject
{
@@ -188,7 +188,7 @@ int MainApp::barIndex(qreal frequency) const
int main(int argc, char *argv[])
{
QGuiApplication app(argc, argv);
- app.setApplicationName("QtDataVis3D spectrum analyzer");
+ app.setApplicationName("QtDataVisualization spectrum analyzer");
Q3DBars window;
window.resize(1024, 768);
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in